summaryrefslogtreecommitdiff
path: root/src/dcp_time.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/dcp_time.h')
-rw-r--r--src/dcp_time.h10
1 files changed, 8 insertions, 2 deletions
diff --git a/src/dcp_time.h b/src/dcp_time.h
index dcbadf31..dbfdb7f0 100644
--- a/src/dcp_time.h
+++ b/src/dcp_time.h
@@ -127,10 +127,16 @@ public:
double as_seconds () const;
/** @param tcr_ Timecode rate with which the return value should be counted
+ * @return the total number of editable units that this time consists of at the specified timecode rate, rounded down
+ * to the nearest editable unit. For example, as_editable_units_floor(24) returns the total time in frames at 24fps.
+ */
+ int64_t as_editable_units_floor (int tcr_) const;
+
+ /** @param tcr_ Timecode rate with which the return value should be counted
* @return the total number of editable units that this time consists of at the specified timecode rate, rounded up
* to the nearest editable unit. For example, as_editable_units (24) returns the total time in frames at 24fps.
*/
- int64_t as_editable_units (int tcr_) const;
+ int64_t as_editable_units_ceil (int tcr_) const;
/** @param tcr_ New timecode rate
* @return A new Time which is this time at the spcified new timecode rate
@@ -127,10 +127,16 @@ public:
* @return the total number of editable units that this time consists of at the specified timecode rate, rounded up
- * to the nearest editable unit. For example, as_editable_units (24) returns the total time in frames at 24fps.
+ * to the nearest editable unit. For example, as_editable_units_ceil(24) returns the total time in frames at 24fps.
*/